pub fn export_tree(
store: &RequirementsStore,
root_id: &str,
) -> Result<ExportedTree>Expand description
Export a requirement and all its descendants to an ExportedTree
pub fn export_tree(
store: &RequirementsStore,
root_id: &str,
) -> Result<ExportedTree>Export a requirement and all its descendants to an ExportedTree