Node identity and workspace configuration for distributed AIDA.
A node is a single clone/installation of AIDA. Each node gets a unique
sequential integer ID via the git CAS push loop at aida init. After
registration, the node can generate globally unique object IDs offline
indefinitely.
A workspace groups multiple code repos that share a single AIDA database. The workspace config is discovered by walking up the directory tree.
Structs
- Agreed
Counters - Per-type counters for agreed IDs assigned at merge-to-trunk.
- Node
Config - Information about a registered node (persisted locally, gitignored).
- Node
Registry - The shared node registry (committed to git, append-only).
- Node
Registry Entry - A node registration entry in the shared registry (committed to git).
- User
Registry - The shared user registry (committed to git, append-only).
- User
Registry Entry - A user registration entry in the shared registry.
- Workspace
Config - Workspace configuration — discovered by walking up the directory tree.
Enums
- Deployment
Mode - The deployment mode for an AIDA instance.